@@ -1,3 +1,19 @@
+/*
+ * itcl.h --
+ *
+ * This file contains definitions for the C-implemeted part of a Itcl
+ * this version of [incr Tcl] (Itcl) is a completely new implementation
+ * based on TclOO extension of Tcl 8.5
+ * It tries to provide the same interfaces as the original implementation
+ * of Michael J. McLennan
+ * Some small pieces of code are taken from that implementation
+ *
+ * Copyright (c) 2007 by Arnulf P. Wiedemann
+ *
+ * See the file "license.terms" for information on usage and redistribution of
+ * this file, and for a DISCLAIMER OF ALL WARRANTIES.
+ */
+
 /*
  * ------------------------------------------------------------------------
  *      PACKAGE:  [incr Tcl]
@@ -11,7 +27,7 @@
  *  it encourages better organization of Tcl applications through the
  *  object-oriented paradigm, leading to code that is easier to
  *  understand and maintain.
- *  
+ *
  *  ADDING [incr Tcl] TO A Tcl-BASED APPLICATION:
  *
  *    To add [incr Tcl] facilities to a Tcl application, modify the
@@ -21,109 +37,89 @@
  *       Tcl_AppInit():
  *
  *         #include "itcl.h"
- *
+*
  *    2) Within the body of Tcl_AppInit(), add the following lines:
  *
  *         if (Itcl_Init(interp) == TCL_ERROR) {
  *             return TCL_ERROR;
  *         }
- * 
+ *
  *    3) Link your application with libitcl.a
  *
  *    NOTE:  An example file "tclAppInit.c" containing the changes shown
  *           above is included in this distribution.
- *  
- * ========================================================================
- *  AUTHOR:  Michael J. McLennan
- *           Bell Labs Innovations for Lucent Technologies
- *           mmclennan@lucent.com
- *           http://www.tcltk.com/itcl
- * ========================================================================
- *           Copyright (c) 1993-1998  Lucent Technologies, Inc.
- * ------------------------------------------------------------------------
- * See the file "license.terms" for information on usage and redistribution
- * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
+ *
+ *---------------------------------------------------------------------
  */
-#ifndef ITCL_H
-#define ITCL_H
 
-#include "tcl.h"
+#ifndef ITCL_H_INCLUDED
+#define ITCL_H_INCLUDED
+
+#include <tcl.h>
+
+#if (TCL_MAJOR_VERSION == 8) && (TCL_MINOR_VERSION < 6)
+#    error Itcl 4 build requires tcl.h from Tcl 8.6 or later
+#endif
+
+/*
+ * For C++ compilers, use extern "C"
+ */
+
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 #ifndef TCL_ALPHA_RELEASE
-#   define TCL_ALPHA_RELEASE	0
+#   define TCL_ALPHA_RELEASE    0
 #endif
 #ifndef TCL_BETA_RELEASE
-#   define TCL_BETA_RELEASE	1
+#   define TCL_BETA_RELEASE     1
 #endif
 #ifndef TCL_FINAL_RELEASE
-#   define TCL_FINAL_RELEASE	2
+#   define TCL_FINAL_RELEASE    2
 #endif
 
+#define ITCL_MAJOR_VERSION	4
+#define ITCL_MINOR_VERSION	1
+#define ITCL_RELEASE_LEVEL      TCL_FINAL_RELEASE
+#define ITCL_RELEASE_SERIAL     1
 
-#define ITCL_MAJOR_VERSION	3
-#define ITCL_MINOR_VERSION	4
-#define ITCL_RELEASE_LEVEL	TCL_FINAL_RELEASE
-#define ITCL_RELEASE_SERIAL	4
+#define ITCL_VERSION            "4.1"
+#define ITCL_PATCH_LEVEL        "4.1.1"
 
-#define ITCL_VERSION		"3.4"
-#define ITCL_PATCH_LEVEL	"3.4.4"
 
-/* 
- * A special definition used to allow this header file to be included 
- * in resource files so that they can get obtain version information from
- * this file.  Resource compilers don't like all the C stuff, like typedefs
- * and procedure declarations, that occur below.
+/*
+ * A special definition used to allow this header file to be included from
+ * windows resource files so that they can obtain version information.
+ * RC_INVOKED is defined by default by the windows RC tool.
+ *
+ * Resource compilers don't like all the C stuff, like typedefs and function
+ * declarations, that occur below, so block them out.
  */
 
 #ifndef RC_INVOKED
 
-#undef TCL_STORAGE_CLASS
-#ifdef BUILD_itcl
-#   define TCL_STORAGE_CLASS DLLEXPORT
-#else
-#   ifdef USE_ITCL_STUBS
-#	define TCL_STORAGE_CLASS
+#define ITCL_NAMESPACE          "::itcl"
+
+#ifndef ITCLAPI
+#   if defined(BUILD_itcl)
+#	define ITCLAPI MODULE_SCOPE
 #   else
-#	define TCL_STORAGE_CLASS DLLIMPORT
+#	define ITCLAPI extern
+#	undef USE_ITCL_STUBS
+#	define USE_ITCL_STUBS 1
 #   endif
 #endif
 
-/*
- * Fix the Borland bug that's in the EXTERN macro from tcl.h.
- */
-#ifndef TCL_EXTERN
-#   undef DLLIMPORT
-#   undef DLLEXPORT
-#   ifdef __cplusplus
-#	define TCL_EXTERNC extern "C"
-#   else
-#	define TCL_EXTERNC extern
-#   endif
-#   if defined(STATIC_BUILD)
-#	define DLLIMPORT
-#	define DLLEXPORT
-#	define TCL_EXTERN(RTYPE) TCL_EXTERNC RTYPE
-#   elif (defined(__WIN32__) && ( \
-	    defined(_MSC_VER) || (__BORLANDC__ >= 0x0550) || \
-	    defined(__LCC__) || defined(__WATCOMC__) || \
-	    (defined(__GNUC__) && defined(__declspec)) \
-	)) || (defined(MAC_TCL) && FUNCTION_DECLSPEC)
-#	define DLLIMPORT __declspec(dllimport)
-#	define DLLEXPORT __declspec(dllexport)
-#	define TCL_EXTERN(RTYPE) TCL_EXTERNC TCL_STORAGE_CLASS RTYPE
-#   elif defined(__BORLANDC__)
-#	define DLLIMPORT __import
-#	define DLLEXPORT __export
-	/* Pre-5.5 Borland requires the attributes be placed after the */
-	/* return type instead. */
-#	define TCL_EXTERN(RTYPE) TCL_EXTERNC RTYPE TCL_STORAGE_CLASS
-#   else
-#	define DLLIMPORT
-#	define DLLEXPORT
-#	define TCL_EXTERN(RTYPE) TCL_EXTERNC TCL_STORAGE_CLASS RTYPE
-#   endif
+#if defined(BUILD_itcl) && !defined(STATIC_BUILD)
+#   define ITCL_EXTERN extern DLLEXPORT
+#else
+#   define ITCL_EXTERN extern
 #endif
 
+ITCL_EXTERN int Itcl_Init(Tcl_Interp *interp);
+ITCL_EXTERN int Itcl_SafeInit(Tcl_Interp *interp);
+
 /*
  * Protection levels:
  *
@@ -136,7 +132,6 @@
 #define ITCL_PRIVATE          3
 #define ITCL_DEFAULT_PROTECT  4
 
-
 /*
  *  Generic stack.
  */
@@ -179,39 +174,30 @@ typedef struct Itcl_List {
  */
 typedef struct Itcl_InterpState_ *Itcl_InterpState;
 
-
+
 /*
- * Include the public function declarations that are accessible via
- * the stubs table.
+ * Include all the public API, generated from itcl.decls.
  */
 
 #include "itclDecls.h"
 
-
-/*
- * Itcl_InitStubs is used by extensions like Itk that can be linked
- * against the itcl stubs library.  If we are not using stubs
- * then this reduces to package require.
- */
-
-#ifdef USE_ITCL_STUBS
-
-TCL_EXTERNC CONST char *
-	Itcl_InitStubs _ANSI_ARGS_((Tcl_Interp *interp,
-			    CONST char *version, int exact));
-#else
-#define Itcl_InitStubs(interp, version, exact) \
-      Tcl_PkgRequire(interp, "Itcl", version, exact)
+#ifdef ITCL_PRESERVE_DEBUG
+#undef Itcl_PreserveData
+#undef Itcl_ReleaseData
+void ItclDbgPreserveData(ClientData cdata, int line, const char *file);
+void ItclDbgReleaseData(ClientData cdata, int line, const char *file);
+#define Itcl_PreserveData(addr) ItclDbgPreserveData(addr, __LINE__, __FILE__)
+#define Itcl_ReleaseData(addr) ItclDbgReleaseData(addr, __LINE__, __FILE__)
 #endif
 
-/*
- * Public functions that are not accessible via the stubs table.
- */
-
-
 #endif /* RC_INVOKED */
 
-#undef TCL_STORAGE_CLASS
-#define TCL_STORAGE_CLASS DLLIMPORT
+/*
+ * end block for C++
+ */
 
-#endif /* ITCL_H */
+#ifdef __cplusplus
+}
+#endif
+
+#endif /* ITCL_H_INCLUDED */
